"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dropbox_common_1 = require("./dropbox.common");
var Dropbox = (function (_super) {
    __extends(Dropbox, _super);
    function Dropbox() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Dropbox.init = function (accessToken) {
        if (!Dropbox.client) {
            var requestConfig = com.dropbox.core.DbxRequestConfig.newBuilder("nativescript-dropbox").build();
            Dropbox.client = new com.dropbox.core.v2.DbxClientV2(requestConfig, accessToken);
        }
    };
    Dropbox.dispose = function () {
        if (Dropbox.client) {
            Dropbox.client = null;
        }
    };
    Dropbox.prototype.createSharedLink = function (path) {
        var instance = this;
        new org.nativescript.plugins.dropbox.ShareFileTask(path, Dropbox.client, new org.nativescript.plugins.dropbox.DropboxPluginListener({
            success: function (result) {
                if (instance.hasListeners(Dropbox.successEvent)) {
                    var eventData = {
                        eventName: Dropbox.successEvent,
                        object: instance,
                        result: result.url,
                        android: result
                    };
                    instance.notify(eventData);
                }
            },
            error: function (error) {
                if (instance.hasListeners(Dropbox.errorEvent)) {
                    var eventData = {
                        eventName: Dropbox.errorEvent,
                        object: instance,
                        android: error
                    };
                    instance.notify(eventData);
                }
            }
        })).execute(null);
    };
    Dropbox.prototype.uploadData = function (path, data, overwrite, autorename, mute) {
        if (overwrite === void 0) { overwrite = true; }
        if (autorename === void 0) { autorename = false; }
        if (mute === void 0) { mute = false; }
        var instance = this, overwriteMode = overwrite ? com.dropbox.core.v2.files.WriteMode.OVERWRITE : com.dropbox.core.v2.files.WriteMode.ADD;
        new org.nativescript.plugins.dropbox.UploadFileTask(path, overwriteMode, autorename, mute, data, Dropbox.client, new org.nativescript.plugins.dropbox.DropboxPluginProgressListener({
            success: function (result) {
                if (instance.hasListeners(Dropbox.successEvent)) {
                    var eventData = {
                        eventName: Dropbox.successEvent,
                        object: instance,
                        android: result
                    };
                    instance.notify(eventData);
                }
            },
            error: function (error) {
                if (instance.hasListeners(Dropbox.errorEvent)) {
                    var eventData = {
                        eventName: Dropbox.errorEvent,
                        object: instance,
                        android: error
                    };
                    instance.notify(eventData);
                }
            },
            progress: function (totalBytesUploaded, totalBytesExpectedToUploaded) {
                if (instance.hasListeners(Dropbox.progressEvent)) {
                    var eventData = {
                        eventName: Dropbox.progressEvent,
                        object: instance,
                        totalBytesUploaded: totalBytesUploaded,
                        totalBytesExpectedToUploaded: totalBytesExpectedToUploaded
                    };
                    instance.notify(eventData);
                }
            }
        })).execute(null);
    };
    return Dropbox;
}(dropbox_common_1.Common));
exports.Dropbox = Dropbox;
//# sourceMappingURL=dropbox.android.js.map