"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dropbox_common_1 = require("./dropbox.common");
var Dropbox = (function (_super) {
    __extends(Dropbox, _super);
    function Dropbox() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Dropbox.init = function (accessToken) {
        if (!Dropbox.client) {
            Dropbox.client = DBUserClient.alloc().initWithAccessToken(accessToken);
        }
    };
    Dropbox.dispose = function () {
        if (Dropbox.client) {
            Dropbox.client = null;
        }
    };
    Dropbox.prototype.createSharedLink = function (path) {
        var _this = this;
        Dropbox.client.sharingRoutes.createSharedLink(path)
            .setResponseBlock(function (result, routeError, networkError) {
            if (result) {
                if (_this.hasListeners(Dropbox.successEvent)) {
                    var eventData = {
                        eventName: Dropbox.successEvent,
                        object: _this,
                        result: result.url,
                        ios: result
                    };
                    _this.notify(eventData);
                }
            }
            else {
                if (_this.hasListeners(Dropbox.errorEvent)) {
                    var eventData = {
                        eventName: Dropbox.errorEvent,
                        object: _this,
                        ios: routeError || networkError
                    };
                    _this.notify(eventData);
                }
            }
        });
    };
    Dropbox.prototype.uploadData = function (path, data, overwrite, autorename, mute) {
        var _this = this;
        if (overwrite === void 0) { overwrite = true; }
        if (autorename === void 0) { autorename = false; }
        if (mute === void 0) { mute = false; }
        var writeMode = DBFILESWriteMode.alloc();
        if (overwrite) {
            writeMode = writeMode.initWithOverwrite();
        }
        else {
            writeMode = writeMode.initWithAdd();
        }
        Dropbox.client.filesRoutes
            .uploadDataModeAutorenameClientModifiedMutePropertyGroupsStrictConflictInputData(path, writeMode, autorename, null, mute, null, false, data)
            .setResponseBlock(function (result, routeError, networkError) {
            if (result) {
                if (_this.hasListeners(Dropbox.successEvent)) {
                    var eventData = {
                        eventName: Dropbox.successEvent,
                        object: _this,
                        ios: result
                    };
                    _this.notify(eventData);
                }
            }
            else {
                if (_this.hasListeners(Dropbox.errorEvent)) {
                    var eventData = {
                        eventName: Dropbox.errorEvent,
                        object: _this,
                        ios: routeError || networkError
                    };
                    _this.notify(eventData);
                }
            }
        })
            .setProgressBlock(function (bytesUploaded, totalBytesUploaded, totalBytesExpectedToUploaded) {
            if (_this.hasListeners(Dropbox.progressEvent)) {
                var eventData = {
                    eventName: Dropbox.progressEvent,
                    object: _this,
                    totalBytesUploaded: totalBytesUploaded,
                    totalBytesExpectedToUploaded: totalBytesExpectedToUploaded
                };
                _this.notify(eventData);
            }
        });
    };
    return Dropbox;
}(dropbox_common_1.Common));
exports.Dropbox = Dropbox;
//# sourceMappingURL=dropbox.ios.js.map